@@ -31,6 +31,7 @@ from tropofy.app import LoadedApps
 from tropofy.database.tropofy_orm import DynamicSchemaName
 from celery import current_task
 from celery.result import AsyncResult
+import re
 
 
 class TaskMessage(object):
@@ -106,7 +107,10 @@ class AppDataSet(ORMBase):
         :type message: string, or list of strings. If list, each element is a separate message written on a new line.
         """
         msg_strings = message if not isinstance(message, basestring) else [message]
-        new_messages = [TaskMessage(text=msg, status=status) for msg in msg_strings]
+        new_messages = []
+        for msg in msg_strings:
+            for msg_split_new_lines in re.split("<br>|\n", msg):  # A lot of code (often third party), adds newlines with <br> or \n explicitly into them. This will strip these and make new lines.
+                new_messages.append(TaskMessage(text=msg_split_new_lines, status=status))
 
         try:  # Using Celery
             current_task._running_task_meta.add_messages(new_messages)
