@@ -235,7 +235,7 @@ def invoke_localsolver_using_lsp_file(data_set, input_file_name):
     with open(solution_file_path) as f:
         content = f.readlines()
         if content:
-            data_set.send_progress_message(out.replace("\n", "<br>"))
+            data_set.send_progress_message(out)
             items = KnapsackItem.get_ordered_list_of_all_items(data_set)
             item_indexes_in_knapsack = [int(i) for i in content]
             for i, item in enumerate(items):
