@@ -21,7 +21,7 @@ from simplekml import Kml, Style, IconStyle, Icon, LineStyle
 from tropofy.app import AppWithDataSets, Step, StepGroup
 from tropofy.widgets import ExecuteFunction, SimpleGrid, KMLMap, Chart
 from tropofy.database.tropofy_orm import DataSetMixin
-from tropofy.database import read_write_xl
+from tropofy.file_io import read_write_xl
 
 
 class Shop(DataSetMixin):
@@ -332,5 +332,6 @@ def formulate_and_solve_facility_location_problem(data_set):
     data_set.send_progress_message("Finished")
 
 
-def load_brisbane_data(data_set):  # Post code geocode data sourced from http://blog.orite.com.au/wp-content/uploads/2009/01/aupcgeo.7z
-    read_write_xl.load_data_from_excel_file_on_disk(data_set, data_set.app.get_path_of_file_in_app_folder('facility_location_example_data.xlsx'))
+# Post code geocode data sourced from http://blog.orite.com.au/wp-content/uploads/2009/01/aupcgeo.7z
+def load_brisbane_data(data_set):
+    read_write_xl.ExcelReader.load_data_from_excel_file_on_disk(data_set, data_set.app.get_path_of_file_in_app_folder('facility_location_example_data.xlsx'))
